Package: evalITR
Title: Evaluating Individualized Treatment Rules
Version: 1.0.0
Date: 2023-08-20
Authors@R: c(
    person("Michael Lingzhi", "Li", , "mili@hbs.edu", role = c("aut", "cre")),
    person("Kosuke", "Imai", , "imai@harvard.edu", role = "aut"),
    person("Jialu", "Li", , "jialu_li@g.harvard.edu", role = "ctb"),
    person("Xiaolong", "Yang", , "xiaolong_yang@g.harvard.edu", role = "ctb")
  )
Maintainer: Michael Lingzhi Li <mili@hbs.edu>
Description: Provides various statistical methods for evaluating
    Individualized Treatment Rules under randomized data. The provided
    metrics include Population Average Value (PAV), Population Average
    Prescription Effect (PAPE), Area Under Prescription Effect Curve
    (AUPEC). It also provides the tools to analyze Individualized
    Treatment Rules under budget constraints. Detailed reference in Imai
    and Li (2019) <arXiv:1905.05389>.
License: GPL (>= 2)
URL: https://github.com/MichaelLLi/evalITR,
        https://michaellli.github.io/evalITR/,
        https://jialul.github.io/causal-ml/
BugReports: https://github.com/MichaelLLi/evalITR/issues
Depends: dplyr (>= 1.0), MASS (>= 7.0), Matrix (>= 1.0), quadprog (>=
        1.0), R (>= 3.5.0), stats
Imports: caret, cli, e1071, forcats, gbm, ggdist, ggplot2, ggthemes,
        glmnet, grf, haven, purrr, rlang, rpart, rqPen, scales, utils,
        bartCause, SuperLearner
Suggests: doParallel, furrr, knitr, rmarkdown, testthat, bartMachine,
        elasticnet, randomForest, spelling
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.2
Language: en-US
NeedsCompilation: no
Packaged: 2023-08-25 17:31:55 UTC; shazn
Author: Michael Lingzhi Li [aut, cre],
  Kosuke Imai [aut],
  Jialu Li [ctb],
  Xiaolong Yang [ctb]
Repository: CRAN
Date/Publication: 2023-08-25 23:10:06 UTC
Built: R 4.6.0; ; 2026-04-25 13:41:13 UTC; unix
