# Generated by roxygen2: do not edit by hand

S3method(plot,itr)
S3method(print,summary.itr)
S3method(print,summary.test_itr)
S3method(summary,itr)
S3method(summary,test_itr)
export(AUPEC)
export(AUPECcv)
export(GATE)
export(GATEcv)
export(PAPD)
export(PAPDcv)
export(PAPE)
export(PAPEcv)
export(PAV)
export(PAVcv)
export(consist.test)
export(consistcv.test)
export(estimate_itr)
export(evaluate_itr)
export(het.test)
export(hetcv.test)
export(plot_estimate)
export(test_itr)
import(dplyr)
import(ggplot2)
import(ggthemes)
import(haven)
import(rpart)
importFrom(MASS,ginv)
importFrom(MASS,mvrnorm)
importFrom(Matrix,nearPD)
importFrom(SuperLearner,SuperLearner)
importFrom(cli,cat_rule)
importFrom(dplyr,ntile)
importFrom(dplyr,pull)
importFrom(ggplot2,.data)
importFrom(purrr,map)
importFrom(quadprog,solve.QP)
importFrom(rlang,"!!")
importFrom(rlang,.data)
importFrom(rlang,sym)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,cov)
importFrom(stats,gaussian)
importFrom(stats,model.matrix)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
